@@ -6,7 +6,7 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 our %SPEC;
 
@@ -41,6 +41,7 @@ sub head {
 1;
 # ABSTRACT: Output the first items of data
 
+
 __END__
 =pod
 
@@ -50,7 +51,25 @@ Data::Unixish::head - Output the first items of data
 
 =head1 VERSION
 
-version 1.23
+version 1.24
+
+=head1 SYNOPSIS
+
+In Perl:
+
+ use Data::Unixish::head;
+ my $in  = [1..100];
+ my $out = [];
+ Data::Unixish::head::head(in=>$in, out=>$out); # $out = [1..10]
+
+In command line:
+
+ % seq 1 100 | dux head -n 20 | dux tail --format=text-simple -n 5
+ 16
+ 17
+ 18
+ 19
+ 20
 
 =head1 DESCRIPTION
 
