@@ -6,7 +6,7 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 our %SPEC;
 
@@ -47,6 +47,7 @@ sub tail {
 1;
 # ABSTRACT: Output the last items of data
 
+
 __END__
 =pod
 
@@ -56,7 +57,25 @@ Data::Unixish::tail - Output the last items of data
 
 =head1 VERSION
 
-version 1.23
+version 1.24
+
+=head1 SYNOPSIS
+
+In Perl:
+
+ use Data::Unixish::tail;
+ my $in  = [1..100];
+ my $out = [];
+ Data::Unixish::tail::tail(in=>$in, out=>$out); # $out = [91..100]
+
+In command line:
+
+ % seq 1 100 | dux tail --format=text-simple -n 5
+ 96
+ 97
+ 98
+ 99
+ 100
 
 =head1 DESCRIPTION
 
